==> elasticsearch-0.20.6-sources.jar: org/elasticsearch/indices/warmer/IndicesWarmer.java <==
/*
 * Licensed to ElasticSearch and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. ElasticSearch licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.indices.warmer;

import org.elasticsearch.cluster.metadata.IndexMetaData;
import org.elasticsearch.index.engine.Engine;
import org.elasticsearch.index.shard.ShardId;
import org.elasticsearch.index.shard.service.IndexShard;

/**
 */
public interface IndicesWarmer {

    static interface Listener {

        String executor();

        void warm(IndexShard indexShard, IndexMetaData indexMetaData, WarmerContext context);
    }

    public static class WarmerContext {

        private final ShardId shardId;

        private final Engine.Searcher fullSearcher;
        private final Engine.Searcher newSearcher;

        public WarmerContext(ShardId shardId, Engine.Searcher fullSearcher, Engine.Searcher newSearcher) {
            this.shardId = shardId;
            this.fullSearcher = fullSearcher;
            this.newSearcher = newSearcher;
        }

        public ShardId shardId() {
            return shardId;
        }

        public Engine.Searcher fullSearcher() {
            return fullSearcher;
        }

        public Engine.Searcher newSearcher() {
            return newSearcher;
        }
    }

    void addListener(Listener listener);

    void removeListener(Listener listener);
}

==> elasticsearch-0.90.1-sources.jar: org/elasticsearch/indices/warmer/IndicesWarmer.java <==
/*
 * Licensed to ElasticSearch and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. ElasticSearch licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.indices.warmer;

import org.elasticsearch.cluster.metadata.IndexMetaData;
import org.elasticsearch.index.engine.Engine;
import org.elasticsearch.index.shard.ShardId;
import org.elasticsearch.index.shard.service.IndexShard;
import org.elasticsearch.threadpool.ThreadPool;

/**
 */
public interface IndicesWarmer {

    public abstract class Listener {

        public String executor() {
            return ThreadPool.Names.WARMER;
        }

        public abstract void warm(IndexShard indexShard, IndexMetaData indexMetaData, WarmerContext context);
    }

    public static class WarmerContext {

        private final ShardId shardId;

        private final Engine.Searcher fullSearcher;
        private final Engine.Searcher newSearcher;

        public WarmerContext(ShardId shardId, Engine.Searcher fullSearcher, Engine.Searcher newSearcher) {
            this.shardId = shardId;
            this.fullSearcher = fullSearcher;
            this.newSearcher = newSearcher;
        }

        public ShardId shardId() {
            return shardId;
        }

        public Engine.Searcher fullSearcher() {
            return fullSearcher;
        }

        public Engine.Searcher newSearcher() {
            return newSearcher;
        }
    }

    void addListener(Listener listener);

    void removeListener(Listener listener);
}
